@@ -9,11 +9,11 @@ Test::Valgrind::Suppressions - Placeholder for architecture-dependant perl suppr
 
 =head1 VERSION
 
-Version 0.01
+Version 0.06
 
 =cut
 
-our $VERSION = '0.01';
+our $VERSION = '0.06';
 
 =head1 DESCRIPTION
 
@@ -21,13 +21,13 @@ L<Test::Valgrind> needs suppressions so that perl's errors aren't reported. Howe
 
 =head1 FUNCTIONS
 
-=head2 C<supppath>
+=head2 C<supp_path>
 
 Returns the path to the suppression file that applies to the current running perl, or C<undef> when no such file is available.
 
 =cut
 
-sub supppath {
+sub supp_path {
  my $pkg = __PACKAGE__;
  $pkg =~ s!::!/!g;
  $pkg .= '.pm';
@@ -37,16 +37,29 @@ sub supppath {
  return (-f $supp) ? $supp : undef;
 }
 
+=head1 CONSTANTS
+
+=head2 C<VG_PATH>
+
+The path to the valgrind binary from which the suppressions were generated.
+
+=cut
+
+use constant VG_PATH => undef;
+
 =head1 EXPORT
 
-This module exports the L</supppath> function only on demand, either by giving its name, or by the C<:funcs> or C<:all> tags.
+This module exports the L</supp_path> function and the L</VG_PATH> constants only on demand, either by giving their name explicitely or by the C<:funcs>, C<:consts> or C<:all> tags.
 
 =cut
 
 use base qw/Exporter/;
 
 our @EXPORT         = ();
-our %EXPORT_TAGS    = ( 'funcs' =>  [ qw/supppath/ ] );
+our %EXPORT_TAGS    = (
+ 'funcs'  => [ qw/supp_path/ ],
+ 'consts' => [ qw/VG_PATH/ ]
+);
 our @EXPORT_OK      = map { @$_ } values %EXPORT_TAGS;
 $EXPORT_TAGS{'all'} = [ @EXPORT_OK ];
 
@@ -74,8 +87,7 @@ You can find documentation for this module with the perldoc command.
 
 Copyright 2008 Vincent Pit, all rights reserved.
 
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
 =cut
 
